pub struct YahooFinanceClient { /* private fields */ }Expand description
Client used for holding data for a ticker. All in one package for requesting and analysing data
Implementations
Sourceimpl YahooFinanceClient
impl YahooFinanceClient
Sourcepub async fn new() -> Result<Self, Box<dyn Error>>
pub async fn new() -> Result<Self, Box<dyn Error>>
Examples found in repository?
examples/aapl.rs (line 13)
12async fn main() {
13 let mut client = YahooFinanceClient::new().await.unwrap();
14 let output = client.fetch_quote_summary("AAPL").await.unwrap();
15
16 let mut equity = client.fetch_historical("AAPL").await.unwrap();
17 println!(
18 "Today's price: {:?}",
19 equity.historical_data.close[equity.historical_data.close.len() - 1]
20 );
21 let current_rsi = equity.current_rsi(14);
22 println!("Current rsi: {:?}", current_rsi);
23
24 println!("Is overbought:{}", equity.is_overvalued().unwrap())
25
26 // println!("{:?}", client);
27 // println!("{:?}", output);
28}Sourcepub async fn fetch_historical(
&mut self,
ticker: &str,
) -> Result<Equity, Box<dyn Error>>
pub async fn fetch_historical( &mut self, ticker: &str, ) -> Result<Equity, Box<dyn Error>>
Fetches the historical data from every day since inception of the ticker price data.
Examples found in repository?
examples/aapl.rs (line 16)
12async fn main() {
13 let mut client = YahooFinanceClient::new().await.unwrap();
14 let output = client.fetch_quote_summary("AAPL").await.unwrap();
15
16 let mut equity = client.fetch_historical("AAPL").await.unwrap();
17 println!(
18 "Today's price: {:?}",
19 equity.historical_data.close[equity.historical_data.close.len() - 1]
20 );
21 let current_rsi = equity.current_rsi(14);
22 println!("Current rsi: {:?}", current_rsi);
23
24 println!("Is overbought:{}", equity.is_overvalued().unwrap())
25
26 // println!("{:?}", client);
27 // println!("{:?}", output);
28}Sourcepub async fn fetch_quote_summary(
&mut self,
symbol: &str,
) -> Result<ApiResponse, Box<dyn Error>>
pub async fn fetch_quote_summary( &mut self, symbol: &str, ) -> Result<ApiResponse, Box<dyn Error>>
Uses current data and formats it into HistoricalData Fetches a summary of what the company behind the ticker does.
Examples found in repository?
examples/aapl.rs (line 14)
12async fn main() {
13 let mut client = YahooFinanceClient::new().await.unwrap();
14 let output = client.fetch_quote_summary("AAPL").await.unwrap();
15
16 let mut equity = client.fetch_historical("AAPL").await.unwrap();
17 println!(
18 "Today's price: {:?}",
19 equity.historical_data.close[equity.historical_data.close.len() - 1]
20 );
21 let current_rsi = equity.current_rsi(14);
22 println!("Current rsi: {:?}", current_rsi);
23
24 println!("Is overbought:{}", equity.is_overvalued().unwrap())
25
26 // println!("{:?}", client);
27 // println!("{:?}", output);
28}Trait Implementations